yt.testing.assert_string_equal — The yt Project 3.2-dev documentation

# yt.testing.assert_string_equal

`yt.testing.` `assert_string_equal`(actual, desired)

  Test if two strings are equal.

  If the given strings are equal, assert_string_equal does nothing. If they are not equal, an AssertionError is raised, and the diff between the strings is shown.

  Parameters: | actual : str The string to test for equality against the expected string. desired : str The expected string.

  Examples

      >>> np.testing.assert_string_equal('abc', 'abc')
      >>> np.testing.assert_string_equal('abc', 'abcd')
      Traceback (most recent call last):
        File "<stdin>", line 1, in <module>
      ...
      AssertionError: Differences in strings:
      - abc+ abcd?    +